/*
 * $Id: about.C,v 1.3 1995/01/01 16:31:38 asf Exp $
 */

/*
    This file is part of Addventure
    Copyright (C) 1994, 1995  Allen S. Firstenberg
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <htmlfile.H>

#include "version.H"
#include "addvutil.H"
#include "setaddv.H"
#include "nextroom.H"
#include "stat.H"

/***************************************************************************/

void copyright_info( HtmlFile *f ){
  f->puts( "This is <b>Addventure</b> version " );
  f->puts( VERSION_NUM );
  f->puts( " - " );
  f->puts( VERSION_DATE );
  f->para();

  f->puts( "Game Copyright (c) 1994 by Allen S. Firstenberg.\n" );
  f->puts( "Individual segments copyrighted by their authors.\n" );
}

/***************************************************************************/

void game_info( HtmlFile *f, char *filepath ){
  
  SetAddv setting( filepath );
  char *title          = setting.game_title();
  char *version        = setting.version();
  char *started        = setting.date_started();
  char *administrator  = setting.contact();
  char *roomw          = setting.roomword();

  // A title for this secion
  if( title ){
    f->header( 2, title );
  } else {
    f->header( 2, "About this game" );
  }

  // When it was created with what version
  f->puts( "Created " );
  if( started ){
    f->puts( "on " );
    f->puts( started );
    f->puts( ", " );
  }
  f->puts( "using Addventure version " );
  f->puts( version );
  f->para();

  // Some information about the status of the game

  // How many rooms are in the game? (completed and open)
  NextRoom nextroom( filepath );
  int lastroom = (int)nextroom - 1;

  // How many rooms have been completed (check the stats file)
  StatFile stats( filepath, 1 );
  int doneroom = stats.statlist()->count();

  f->puts( "There are currently " );
  f->puts( itoa( doneroom ) );
  f->puts( " " );
  f->puts( roomw );
  f->puts( "s that have been completed out of " );
  f->puts( itoa( lastroom ) );
  f->puts( " currently available.\n" );

  // Insert contact information
  if( administrator ){
    f->puts( "For further information please contact: " );
    f->address( administrator );
    f->para();
  }

}

/***************************************************************************/

main( int argc, char *argv[] ){

  char *urlpath;   // The path relative to the server root
  char *filepath;  // The absolute path in the file system

  urlpath  = getenv( "PATH_INFO" );
  filepath = getenv( "PATH_TRANSLATED" );

  // Send HTML output to the client
  HtmlFile f;
  f.content_type();

  // Send header stuff
  f.title( "About this game." );
  f.header( 1, "About this game." );

  copyright_info( &f );
  f.line();
  game_info( &f, filepath );

}

/***************************************************************************/

/*
 * $Log: about.C,v $
 * Revision 1.3  1995/01/01  16:31:38  asf
 * Added support for the "room word"
 *
 * Revision 1.2  1994/10/03  15:01:27  asf
 * Version information now comes from version.h
 *
 * Revision 1.1  1994/10/01  19:51:42  asf
 * Initial revision
 *
 */
