/*
 * $Id: timefile.C,v 1.2 1994/12/19 20:02:23 asf Exp $
 */

/*
    This file is part of Addventure
    Copyright (C) 1994  Allen S. Firstenberg
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <time.h>

#include "timefile.H"
#include "addvutil.H"

/***************************************************************************/

TimeFile::TimeFile( char *path, int room, char *ext ){
  filename = make_fname( path, room, ext );
}

//---------------------------------------------------------------------------

TimeFile::TimeFile( char *path, char *room, char *ext ){
  filename = make_fname( path, room, ext );
}

//---------------------------------------------------------------------------

TimeFile::~TimeFile(){
  free( filename );
}

//---------------------------------------------------------------------------

int TimeFile::create( int parent ){
  /*
   * Create the openfile.  Return 1 on success, 0 on failure.
   */
  int ret;

  FILE *file;
  time_t t;

  // Open the file
  set_permissions();
  if( file = fopen( filename, "w" ) ){
    // Get the time
    t = time( NULL );

    // Print the time
    fprintf( file, "%d\n", t );

    // Print the parent
    fprintf( file, "%d\n", parent );
    
    fclose( file );
    ret = 1;
  } else {
    ret = 0;
  }

  return ret;
}

/***************************************************************************/

time_t TimeFile::value(){
  /*
   * Return the value that has been stored, or 0 if it failed
   */
  time_t ret;

  FILE *file;
  time_t t;

  // Open the file
  if( file = fopen( filename, "r" ) ){
    // Read the time
    fscanf( file, "%d", &t );
    fclose( file );
    ret = t;
  } else {
    fprintf( stderr, "Timefile: '%s' not opened for time read\n", filename );
    ret = 0;
  }

  return ret;
}

/***************************************************************************/

int TimeFile::parent(){
  /*
   * Return the parent that was stored inthe file
   */
  int ret;

  FILE *file;
  int t;
  char scratch[80];

  // Open the file
  if( file = fopen( filename, "r" ) ){
    // Read the time (and ignore it)
    fgets( scratch, 80, file );

    // Read the parent room
    fscanf( file, "%d", &t );
    ret = t;
    
    fclose( file );
  } else {
    fprintf( stderr, "Timefile: '%s' not opened for parent read\n", filename );
    ret = 0;
  }

  return ret;
  
}

/***************************************************************************/

int TimeFile::exists(){
  /*
   * Return 1 if the file exists and 0 if it does not
   */
  int ret;

  ret = file_exists( filename );

  return ret;
}

/***************************************************************************/

int TimeFile::remove(){
  /*
   * Delete the openfile.  Return 1 on success, 0 on failure.
   */
  int ret;

  if( !unlink( filename ) ){
    // unlink() returns 0 on success
    ret = 1;
  } else {
    ret = 0;
  }

  return ret;
}

/***************************************************************************/

/*
 * $Log: timefile.C,v $
 * Revision 1.2  1994/12/19  20:02:23  asf
 * Improved debugging
 *
 * Revision 1.1  1994/10/01  15:52:27  asf
 * Initial revision
 *
 */
