/*
 * $Id: timeout.C,v 1.8 1995/01/24 19:31:59 asf Exp $
 */

/*
    This file is part of Addventure
    Copyright (C) 1994, 1995  Allen S. Firstenberg
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
 * Return codes:
 *    0 = nothing deleted
 *    1 = file cleaned up
 *   10 = other error
 */

#include <stdlib.h>
#include <stdio.h>
#include <time.h>

#include "opt.H"
#include "setaddv.H"
#include "openfile.H"
#include "cleanup.H"

/***************************************************************************/

void usage( char *program ){
  fprintf( stderr, "Usage:\n" );
  fprintf( stderr, "   %s ", program );
  fprintf( stderr, "-filepath PATH " );
  fprintf( stderr, "-binpath PATH " );
  fprintf( stderr, "-urlpath PATH " );
  fprintf( stderr, "-force " );
  fprintf( stderr, "-room ROOM\n" );
  exit( 10 );
}

/***************************************************************************/

main( int argc, char *argv[] ){

  Opt cla( argc, argv );   // Get the command line arguments

  char *filepath;    // Where the file is
  char *urlpath;
  char *binpath;
  char *room_str;    // The room to review for deletion
  char *force;       // Should we force a cleanup even if its not timed out
  int   room;
  int   parent;

  time_t time_open; // When the room was opened
  time_t time_now;  // What the time is now
  time_t time_max;  // (From configuration file) how long do we keep it open?

  char *roomword;   // What do we call a "room"

  // Read all the command line values
  filepath = cla.get_value( "-filepath" );
  urlpath  = cla.get_value( "-urlpath" );
  binpath  = cla.get_value( "-binpath" );
  force    = cla.get_value( "-force" );
  room_str = cla.get_value( "-room" );

  if( (!filepath) || (!room_str) || (!urlpath) || (!binpath) ){
    // Left out a parameter
    usage( argv[0] );
  } else {
    // Command line parameters existed

    // Where to store the openfile
    OpenFile openfile( filepath, room_str );

    room = atoi( room_str );

    // Load how long can we keep a room open from the game options
    SetAddv settings( filepath );
    time_max = settings.cleanup_after();
    roomword = settings.roomword();

    // What is the current time
    time( &time_now );

    // When was the room opened and with what parent
    time_open = openfile.value();
    parent    = openfile.parent();

    printf( "Timeout: %s %d: ", roomword, room );

    // Compute if we've been open too long and act
    time_t time_diff = time_now - time_open;
    if( (time_max < time_diff) || (force) ){
      // It has been open for too long
      cleanup( room, parent, roomword, filepath, urlpath, binpath );
      if( force ){
        printf( "force " );
      }
      printf( "cleaned\n" );
    } else {
      // Have not yet timed out
      printf( "not cleaned.  %d seconds to go.\n", (time_max-time_diff) );
    }
  }
}

/***************************************************************************/

/*
 * $Log: timeout.C,v $
 * Revision 1.8  1995/01/24  19:31:59  asf
 * Fixed incorrectly ordered parameters to call to cleanup()
 *
 * Revision 1.7  1995/01/01  16:37:40  asf
 * Added support for the "room word"
 *
 * Revision 1.6  1994/12/19  20:09:08  asf
 * Tried to open the OpenFile with "room" (an unassigned integer), not "room_str"
 * (which has the room number.  heavens).
 *
 * Revision 1.5  1994/10/01  15:52:39  asf
 * Switched to use of LockFile and OpenFile.
 *
 * Revision 1.4  1994/09/27  18:55:42  asf
 * Fixed bug that I was checking room to see if it was a pointer rather than
 * room_str.
 *
 * Revision 1.3  1994/09/27  18:15:31  asf
 * Fixed a usage typo.
 *
 * Revision 1.2  1994/09/27  17:42:02  asf
 * Added the -force option to do force cleaning.
 *
 * Revision 1.1  1994/09/27  17:08:09  asf
 * Initial revision
 *
 */
